@@ -1,49 +1,19 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the QtSerialBus module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL3$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
 #include <QtSerialBus/qcanbusdevice.h>
 #include <QtSerialBus/qcanbusframe.h>
 
 #include <QtCore/qtimer.h>
+#include <QtCore/QElapsedTimer>
 #include <QtCore/QtPlugin>
 #include <QtTest/qsignalspy.h>
 #include <QtTest/qtest.h>
 
 #include <memory>
 
+using namespace Qt::StringLiterals;
+
 Q_DECLARE_METATYPE(QCanBusDevice::Filter)
 
 class tst_Backend : public QCanBusDevice
@@ -121,11 +91,11 @@ public:
     QCanBusDeviceInfo deviceInfo() const override
     {
         return createDeviceInfo(
-            u"plugin"_qs,
-            u"name"_qs,
-            u"serial number"_qs,
-            u"description"_qs,
-            u"alias"_qs,
+            u"plugin"_s,
+            u"name"_s,
+            u"serial number"_s,
+            u"description"_s,
+            u"alias"_s,
             100,    //channel
             true,   // virtual
             true    // flexible data rate
@@ -199,7 +169,7 @@ void tst_QCanBusDevice::initTestCase()
     QVERIFY(device->connectDevice());
     QCOMPARE(device->error(), QCanBusDevice::NoError);
     QTRY_VERIFY_WITH_TIMEOUT(device->state() == QCanBusDevice::ConnectedState, 5000);
-    QCOMPARE(stateSpy.count(), 4);
+    QCOMPARE(stateSpy.size(), 4);
     QCOMPARE(stateSpy.at(0).at(0).value<QCanBusDevice::CanBusDeviceState>(),
              QCanBusDevice::ConnectingState);
     QCOMPARE(stateSpy.at(1).at(0).value<QCanBusDevice::CanBusDeviceState>(),
@@ -251,7 +221,7 @@ void tst_QCanBusDevice::write()
 
     device->disconnectDevice();
     QTRY_VERIFY_WITH_TIMEOUT(device->state() == QCanBusDevice::UnconnectedState, 5000);
-    QCOMPARE(stateSpy.count(), 2);
+    QCOMPARE(stateSpy.size(), 2);
     QCOMPARE(stateSpy.at(0).at(0).value<QCanBusDevice::CanBusDeviceState>(),
              QCanBusDevice::ClosingState);
     QCOMPARE(stateSpy.at(1).at(0).value<QCanBusDevice::CanBusDeviceState>(),
@@ -261,11 +231,11 @@ void tst_QCanBusDevice::write()
 
     QVERIFY(!device->writeFrame(frame));
     QCOMPARE(device->error(), QCanBusDevice::OperationError);
-    QCOMPARE(spy.count(), 0);
+    QCOMPARE(spy.size(), 0);
 
     device->connectDevice();
     QTRY_VERIFY_WITH_TIMEOUT(device->state() == QCanBusDevice::ConnectedState, 5000);
-    QCOMPARE(stateSpy.count(), 2);
+    QCOMPARE(stateSpy.size(), 2);
     QCOMPARE(stateSpy.at(0).at(0).value<QCanBusDevice::CanBusDeviceState>(),
              QCanBusDevice::ConnectingState);
     QCOMPARE(stateSpy.at(1).at(0).value<QCanBusDevice::CanBusDeviceState>(),
@@ -273,7 +243,7 @@ void tst_QCanBusDevice::write()
 
     QVERIFY(device->writeFrame(frame));
     QCOMPARE(device->error(), QCanBusDevice::NoError);
-    QCOMPARE(spy.count(), 1);
+    QCOMPARE(spy.size(), 1);
 }
 
 void tst_QCanBusDevice::read()
@@ -289,7 +259,7 @@ void tst_QCanBusDevice::read()
 
     QVERIFY(device->connectDevice());
     QTRY_VERIFY_WITH_TIMEOUT(device->state() == QCanBusDevice::ConnectedState, 5000);
-    QCOMPARE(stateSpy.count(), 2);
+    QCOMPARE(stateSpy.size(), 2);
     QCOMPARE(stateSpy.at(0).at(0).value<QCanBusDevice::CanBusDeviceState>(),
              QCanBusDevice::ConnectingState);
     QCOMPARE(stateSpy.at(1).at(0).value<QCanBusDevice::CanBusDeviceState>(),
@@ -369,7 +339,7 @@ void tst_QCanBusDevice::clearOutputBuffer()
     QSignalSpy spy(device.get(), &QCanBusDevice::framesWritten);
     for (int i = 0; i < 10; ++i)
         device->writeFrame(QCanBusFrame(0x123, "output"));
-    QTRY_VERIFY_WITH_TIMEOUT(spy.count() == 10, 5000);
+    QTRY_VERIFY_WITH_TIMEOUT(spy.size() == 10, 5000);
 
     // now test clearing the buffer before the frames are actually written
     spy.clear();
@@ -378,7 +348,7 @@ void tst_QCanBusDevice::clearOutputBuffer()
 
     device->clear(QCanBusDevice::Output);
     QCOMPARE(device->error(), QCanBusDevice::NoError);
-    QTRY_VERIFY_WITH_TIMEOUT(spy.count() == 0, 5000);
+    QTRY_VERIFY_WITH_TIMEOUT(spy.size() == 0, 5000);
 }
 
 void tst_QCanBusDevice::error()
@@ -396,31 +366,31 @@ void tst_QCanBusDevice::error()
     backend->emulateError(testString + QStringLiteral("a"), QCanBusDevice::ReadError);
     QCOMPARE(testString + QStringLiteral("a"), device->errorString());
     QCOMPARE(device->error(), 1);
-    QCOMPARE(spy.count(), 1);
+    QCOMPARE(spy.size(), 1);
 
     // WriteError
     backend->emulateError(testString + QStringLiteral("b"), QCanBusDevice::WriteError);
     QCOMPARE(testString + QStringLiteral("b"), device->errorString());
     QCOMPARE(device->error(), 2);
-    QCOMPARE(spy.count(), 2);
+    QCOMPARE(spy.size(), 2);
 
     // ConnectionError
     backend->emulateError(testString + QStringLiteral("c"), QCanBusDevice::ConnectionError);
     QCOMPARE(testString + QStringLiteral("c"), device->errorString());
     QCOMPARE(device->error(), 3);
-    QCOMPARE(spy.count(), 3);
+    QCOMPARE(spy.size(), 3);
 
     // ConfigurationError
     backend->emulateError(testString + QStringLiteral("d"), QCanBusDevice::ConfigurationError);
     QCOMPARE(testString + QStringLiteral("d"), device->errorString());
     QCOMPARE(device->error(), 4);
-    QCOMPARE(spy.count(), 4);
+    QCOMPARE(spy.size(), 4);
 
     // UnknownError
     backend->emulateError(testString + QStringLiteral("e"), QCanBusDevice::UnknownError);
     QCOMPARE(testString + QStringLiteral("e"), device->errorString());
     QCOMPARE(device->error(), 5);
-    QCOMPARE(spy.count(), 5);
+    QCOMPARE(spy.size(), 5);
 }
 
 void tst_QCanBusDevice::cleanupTestCase()
@@ -455,7 +425,7 @@ void tst_QCanBusDevice::tst_filtering()
 
     const QVariant wrapper = QVariant::fromValue(filters);
     const auto newFilter = wrapper.value<QList<QCanBusDevice::Filter> >();
-    QCOMPARE(newFilter.count(), 2);
+    QCOMPARE(newFilter.size(), 2);
 
     QCOMPARE(newFilter.at(0).type, QCanBusFrame::DataFrame);
     QCOMPARE(newFilter.at(0).frameId, 0x1u);
@@ -630,7 +600,7 @@ void tst_QCanBusDevice::tst_waitForFramesReceived()
         device->triggerNewFrame();
     });
     QTimer::singleShot(2000, [&]() { device->triggerNewFrame(); });
-    QObject::connect(device.get(), &QCanBusDevice::framesReceived, [this, &handleCounter]() {
+    QObject::connect(device.get(), &QCanBusDevice::framesReceived, this, [this, &handleCounter]() {
         handleCounter++;
         // this should trigger a recursion which we want to catch
         QVERIFY(!device->waitForFramesReceived(5000));
@@ -717,7 +687,7 @@ void tst_QCanBusDevice::tst_waitForFramesWritten()
     device->writeFrame(frame);
     QTimer::singleShot(1000, [&]() { device->writeFrame(frame); });
     QTimer::singleShot(2000, [&]() { device->writeFrame(frame); });
-    QObject::connect(device.get(), &QCanBusDevice::framesWritten, [this, &handleCounter]() {
+    QObject::connect(device.get(), &QCanBusDevice::framesWritten, this, [this, &handleCounter]() {
         handleCounter++;
         // this should trigger a recursion which we want to catch
         QVERIFY(!device->waitForFramesWritten(5000));
@@ -736,11 +706,11 @@ void tst_QCanBusDevice::tst_deviceInfo()
     QVERIFY(canDevice != nullptr);
 
     auto info = canDevice->deviceInfo();
-    QCOMPARE(info.plugin(), u"plugin"_qs);
-    QCOMPARE(info.name(), u"name"_qs);
-    QCOMPARE(info.serialNumber(), u"serial number"_qs);
-    QCOMPARE(info.description(), u"description"_qs);
-    QCOMPARE(info.alias(), u"alias"_qs);
+    QCOMPARE(info.plugin(), u"plugin"_s);
+    QCOMPARE(info.name(), u"name"_s);
+    QCOMPARE(info.serialNumber(), u"serial number"_s);
+    QCOMPARE(info.description(), u"description"_s);
+    QCOMPARE(info.alias(), u"alias"_s);
     QCOMPARE(info.channel(), 100);
     QCOMPARE(info.hasFlexibleDataRate(), true);
     QCOMPARE(info.isVirtual(), true);
